@@ -338,6 +338,7 @@ instance AttrInfo AssistantPageChildPropertyInfo where
     type AttrOrigin AssistantPageChildPropertyInfo = AssistantPage
     attrGet = getAssistantPageChild
     attrSet = undefined
+    attrPut = undefined
     attrTransfer _ v = do
         unsafeCastTo Gtk.Widget.Widget v
     attrConstruct = constructAssistantPageChild
@@ -380,7 +381,7 @@ constructAssistantPageComplete val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data AssistantPageCompletePropertyInfo
 instance AttrInfo AssistantPageCompletePropertyInfo where
-    type AttrAllowedOps AssistantPageCompletePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps AssistantPageCompletePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint AssistantPageCompletePropertyInfo = IsAssistantPage
     type AttrSetTypeConstraint AssistantPageCompletePropertyInfo = (~) Bool
     type AttrTransferTypeConstraint AssistantPageCompletePropertyInfo = (~) Bool
@@ -390,6 +391,7 @@ instance AttrInfo AssistantPageCompletePropertyInfo where
     type AttrOrigin AssistantPageCompletePropertyInfo = AssistantPage
     attrGet = getAssistantPageComplete
     attrSet = setAssistantPageComplete
+    attrPut = setAssistantPageComplete
     attrTransfer _ v = do
         return v
     attrConstruct = constructAssistantPageComplete
@@ -432,7 +434,7 @@ constructAssistantPagePageType val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data AssistantPagePageTypePropertyInfo
 instance AttrInfo AssistantPagePageTypePropertyInfo where
-    type AttrAllowedOps AssistantPagePageTypePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps AssistantPagePageTypePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint AssistantPagePageTypePropertyInfo = IsAssistantPage
     type AttrSetTypeConstraint AssistantPagePageTypePropertyInfo = (~) Gtk.Enums.AssistantPageType
     type AttrTransferTypeConstraint AssistantPagePageTypePropertyInfo = (~) Gtk.Enums.AssistantPageType
@@ -442,6 +444,7 @@ instance AttrInfo AssistantPagePageTypePropertyInfo where
     type AttrOrigin AssistantPagePageTypePropertyInfo = AssistantPage
     attrGet = getAssistantPagePageType
     attrSet = setAssistantPagePageType
+    attrPut = setAssistantPagePageType
     attrTransfer _ v = do
         return v
     attrConstruct = constructAssistantPagePageType
@@ -503,6 +506,7 @@ instance AttrInfo AssistantPageTitlePropertyInfo where
     type AttrOrigin AssistantPageTitlePropertyInfo = AssistantPage
     attrGet = getAssistantPageTitle
     attrSet = setAssistantPageTitle
+    attrPut = undefined
     attrTransfer _ v = do
         return v
     attrConstruct = constructAssistantPageTitle
