@@ -417,6 +417,7 @@ instance AttrInfo NotebookPageChildPropertyInfo where
     type AttrOrigin NotebookPageChildPropertyInfo = NotebookPage
     attrGet = getNotebookPageChild
     attrSet = undefined
+    attrPut = undefined
     attrTransfer _ v = do
         unsafeCastTo Gtk.Widget.Widget v
     attrConstruct = constructNotebookPageChild
@@ -459,7 +460,7 @@ constructNotebookPageDetachable val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data NotebookPageDetachablePropertyInfo
 instance AttrInfo NotebookPageDetachablePropertyInfo where
-    type AttrAllowedOps NotebookPageDetachablePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps NotebookPageDetachablePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint NotebookPageDetachablePropertyInfo = IsNotebookPage
     type AttrSetTypeConstraint NotebookPageDetachablePropertyInfo = (~) Bool
     type AttrTransferTypeConstraint NotebookPageDetachablePropertyInfo = (~) Bool
@@ -469,6 +470,7 @@ instance AttrInfo NotebookPageDetachablePropertyInfo where
     type AttrOrigin NotebookPageDetachablePropertyInfo = NotebookPage
     attrGet = getNotebookPageDetachable
     attrSet = setNotebookPageDetachable
+    attrPut = setNotebookPageDetachable
     attrTransfer _ v = do
         return v
     attrConstruct = constructNotebookPageDetachable
@@ -511,6 +513,7 @@ instance AttrInfo NotebookPageMenuPropertyInfo where
     type AttrOrigin NotebookPageMenuPropertyInfo = NotebookPage
     attrGet = getNotebookPageMenu
     attrSet = undefined
+    attrPut = undefined
     attrTransfer _ v = do
         unsafeCastTo Gtk.Widget.Widget v
     attrConstruct = constructNotebookPageMenu
@@ -572,6 +575,7 @@ instance AttrInfo NotebookPageMenuLabelPropertyInfo where
     type AttrOrigin NotebookPageMenuLabelPropertyInfo = NotebookPage
     attrGet = getNotebookPageMenuLabel
     attrSet = setNotebookPageMenuLabel
+    attrPut = undefined
     attrTransfer _ v = do
         return v
     attrConstruct = constructNotebookPageMenuLabel
@@ -614,7 +618,7 @@ constructNotebookPagePosition val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data NotebookPagePositionPropertyInfo
 instance AttrInfo NotebookPagePositionPropertyInfo where
-    type AttrAllowedOps NotebookPagePositionPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps NotebookPagePositionPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint NotebookPagePositionPropertyInfo = IsNotebookPage
     type AttrSetTypeConstraint NotebookPagePositionPropertyInfo = (~) Int32
     type AttrTransferTypeConstraint NotebookPagePositionPropertyInfo = (~) Int32
@@ -624,6 +628,7 @@ instance AttrInfo NotebookPagePositionPropertyInfo where
     type AttrOrigin NotebookPagePositionPropertyInfo = NotebookPage
     attrGet = getNotebookPagePosition
     attrSet = setNotebookPagePosition
+    attrPut = setNotebookPagePosition
     attrTransfer _ v = do
         return v
     attrConstruct = constructNotebookPagePosition
@@ -666,7 +671,7 @@ constructNotebookPageReorderable val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data NotebookPageReorderablePropertyInfo
 instance AttrInfo NotebookPageReorderablePropertyInfo where
-    type AttrAllowedOps NotebookPageReorderablePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps NotebookPageReorderablePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint NotebookPageReorderablePropertyInfo = IsNotebookPage
     type AttrSetTypeConstraint NotebookPageReorderablePropertyInfo = (~) Bool
     type AttrTransferTypeConstraint NotebookPageReorderablePropertyInfo = (~) Bool
@@ -676,6 +681,7 @@ instance AttrInfo NotebookPageReorderablePropertyInfo where
     type AttrOrigin NotebookPageReorderablePropertyInfo = NotebookPage
     attrGet = getNotebookPageReorderable
     attrSet = setNotebookPageReorderable
+    attrPut = setNotebookPageReorderable
     attrTransfer _ v = do
         return v
     attrConstruct = constructNotebookPageReorderable
@@ -718,6 +724,7 @@ instance AttrInfo NotebookPageTabPropertyInfo where
     type AttrOrigin NotebookPageTabPropertyInfo = NotebookPage
     attrGet = getNotebookPageTab
     attrSet = undefined
+    attrPut = undefined
     attrTransfer _ v = do
         unsafeCastTo Gtk.Widget.Widget v
     attrConstruct = constructNotebookPageTab
@@ -760,7 +767,7 @@ constructNotebookPageTabExpand val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data NotebookPageTabExpandPropertyInfo
 instance AttrInfo NotebookPageTabExpandPropertyInfo where
-    type AttrAllowedOps NotebookPageTabExpandPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps NotebookPageTabExpandPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint NotebookPageTabExpandPropertyInfo = IsNotebookPage
     type AttrSetTypeConstraint NotebookPageTabExpandPropertyInfo = (~) Bool
     type AttrTransferTypeConstraint NotebookPageTabExpandPropertyInfo = (~) Bool
@@ -770,6 +777,7 @@ instance AttrInfo NotebookPageTabExpandPropertyInfo where
     type AttrOrigin NotebookPageTabExpandPropertyInfo = NotebookPage
     attrGet = getNotebookPageTabExpand
     attrSet = setNotebookPageTabExpand
+    attrPut = setNotebookPageTabExpand
     attrTransfer _ v = do
         return v
     attrConstruct = constructNotebookPageTabExpand
@@ -812,7 +820,7 @@ constructNotebookPageTabFill val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data NotebookPageTabFillPropertyInfo
 instance AttrInfo NotebookPageTabFillPropertyInfo where
-    type AttrAllowedOps NotebookPageTabFillPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps NotebookPageTabFillPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint NotebookPageTabFillPropertyInfo = IsNotebookPage
     type AttrSetTypeConstraint NotebookPageTabFillPropertyInfo = (~) Bool
     type AttrTransferTypeConstraint NotebookPageTabFillPropertyInfo = (~) Bool
@@ -822,6 +830,7 @@ instance AttrInfo NotebookPageTabFillPropertyInfo where
     type AttrOrigin NotebookPageTabFillPropertyInfo = NotebookPage
     attrGet = getNotebookPageTabFill
     attrSet = setNotebookPageTabFill
+    attrPut = setNotebookPageTabFill
     attrTransfer _ v = do
         return v
     attrConstruct = constructNotebookPageTabFill
@@ -883,6 +892,7 @@ instance AttrInfo NotebookPageTabLabelPropertyInfo where
     type AttrOrigin NotebookPageTabLabelPropertyInfo = NotebookPage
     attrGet = getNotebookPageTabLabel
     attrSet = setNotebookPageTabLabel
+    attrPut = undefined
     attrTransfer _ v = do
         return v
     attrConstruct = constructNotebookPageTabLabel
