@@ -136,6 +136,7 @@ import qualified GI.Gsk.Objects.GLShader as Gsk.GLShader
 import qualified GI.Gsk.Objects.RenderNode as Gsk.RenderNode
 import qualified GI.Gsk.Objects.Renderer as Gsk.Renderer
 import qualified GI.Gsk.Structs.ColorStop as Gsk.ColorStop
+import qualified GI.Gsk.Structs.ComponentTransfer as Gsk.ComponentTransfer
 import qualified GI.Gsk.Structs.Path as Gsk.Path
 import qualified GI.Gsk.Structs.RoundedRect as Gsk.RoundedRect
 import qualified GI.Gsk.Structs.Shadow as Gsk.Shadow
@@ -187,18 +188,18 @@ instance B.Types.TypedObject TextChildAnchor where
 
 instance B.Types.GObject TextChildAnchor
 
--- | Type class for types which can be safely cast to `TextChildAnchor`, for instance with `toTextChildAnchor`.
+-- | Type class for types which can be safely cast to t'TextChildAnchor', for instance with `toTextChildAnchor`.
 class (SP.GObject o, O.IsDescendantOf TextChildAnchor o) => IsTextChildAnchor o
 instance (SP.GObject o, O.IsDescendantOf TextChildAnchor o) => IsTextChildAnchor o
 
 instance O.HasParentTypes TextChildAnchor
 type instance O.ParentTypes TextChildAnchor = '[GObject.Object.Object]
 
--- | Cast to `TextChildAnchor`, for types for which this is known to be safe. For general casts, use `Data.GI.Base.ManagedPtr.castTo`.
+-- | Cast to t'TextChildAnchor', for types for which this is known to be safe. For general casts, use 'Data.GI.Base.ManagedPtr.castTo'.
 toTextChildAnchor :: (MIO.MonadIO m, IsTextChildAnchor o) => o -> m TextChildAnchor
 toTextChildAnchor = MIO.liftIO . B.ManagedPtr.unsafeCastTo TextChildAnchor
 
--- | Convert 'TextChildAnchor' to and from 'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
+-- | Convert t'TextChildAnchor' to and from t'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
 instance B.GValue.IsGValue (Maybe TextChildAnchor) where
     gvalueGType_ = c_gtk_text_child_anchor_get_type
     gvalueSet_ gv P.Nothing = B.GValue.set_object gv (FP.nullPtr :: FP.Ptr TextChildAnchor)
@@ -419,7 +420,7 @@ instance (signature ~ (m Bool), MonadIO m, IsTextChildAnchor a) => O.OverloadedM
 instance O.OverloadedMethodInfo TextChildAnchorGetDeletedMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.TextChildAnchor.textChildAnchorGetDeleted",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-TextChildAnchor.html#v:textChildAnchorGetDeleted"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-TextChildAnchor.html#v:textChildAnchorGetDeleted"
         })
 
 
@@ -526,7 +527,7 @@ instance (signature ~ (m [Gtk.Widget.Widget]), MonadIO m, IsTextChildAnchor a) =
 instance O.OverloadedMethodInfo TextChildAnchorGetWidgetsMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.TextChildAnchor.textChildAnchorGetWidgets",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-TextChildAnchor.html#v:textChildAnchorGetWidgets"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-TextChildAnchor.html#v:textChildAnchorGetWidgets"
         })
 
 
